@@ -189,20 +189,15 @@ class _RegressionPlotter(_LinearPlotter):
     def fit_regression(self, ax=None, x_range=None, grid=None):
         """Fit the regression model."""
         # Create the grid for the regression
-        print('foo')
         if grid is None:
             if self.truncate:
                 x_min, x_max = self.x_range
             else:
-                if ax is None:
-                    x_min, x_max = x_range
-                else:
-                    x_min, x_max = ax.get_xlim()
+                raise NotImplementedError('truncate not supported yet')
             grid = np.linspace(x_min, x_max, 100)
         ci = self.ci
 
         # Fit the regression
-        print('order', self.order)
         if self.order > 1:
             yhat, yhat_boots = self.fit_poly(grid, self.order)
         elif self.logistic:
@@ -219,7 +214,6 @@ class _RegressionPlotter(_LinearPlotter):
         elif self.logx:
             yhat, yhat_boots = self.fit_logx(grid)
         else:
-            breakpoint()
             yhat, yhat_boots = self.fit_fast(grid)
 
         # Compute the confidence interval at each grid point
